@@ -35,7 +35,7 @@ static const int FLAG_MAX_WIDTH = 21;
 static const int FLAG_MAX_HEIGHT = 14;
 
 const QString LayoutIcon::flagTemplate("l10n/%1/flag.png");
-const QString& LayoutIcon::ERROR_CODE("error");
+const QString LayoutIcon::ERROR_CODE("error");
 LayoutIcon* LayoutIcon::instance;
 
 
@@ -57,6 +57,7 @@ LayoutIcon::LayoutIcon():
 const QPixmap&
 LayoutIcon::findPixmap(const QString& code_, bool showFlag, const QString& displayName_)
 {
+//kDebug() << "pixmap for" << code_ << displayName_;
 	QPixmap* pm = NULL;
 
 	if( code_ == ERROR_CODE ) {
@@ -71,10 +72,10 @@ LayoutIcon::findPixmap(const QString& code_, bool showFlag, const QString& displ
 	QString displayName(displayName_);
 
 	if( displayName.isEmpty() ) {
-		displayName = KxkbConfig::getDefaultDisplayName(code_);
+	    displayName = LayoutUnit::getDefaultDisplayName(code_);
 	}
-	if( displayName.length() > 3 )
-		displayName = displayName.left(3);
+	if( displayName.length() > MAX_LABEL_LEN )
+	    displayName = displayName.left(MAX_LABEL_LEN);
 
 	const QString pixmapKey( showFlag ? code_ + '.' + displayName : displayName );
 
