@@ -108,8 +108,13 @@ class UserListView : public QListWidget {
 		switch (event->key()) {
 		case Qt::Key_Enter:
 		case Qt::Key_Return:
-			if (currentIndex().isValid())
-				emit activated( currentIndex() );
+			if (currentItem())
+				emit itemDoubleClicked( currentItem() );
+			event->accept();
+			break;
+		case Qt::Key_Space:
+			if (currentItem())
+				emit itemClicked( currentItem() );
 			event->accept();
 			break;
 		default:
@@ -117,6 +122,29 @@ class UserListView : public QListWidget {
 			break;
 		}
 	}
+
+	virtual void mousePressEvent( QMouseEvent *event )
+	{
+		m_suppressClick = false;
+		QListWidget::mousePressEvent(event);
+	}
+
+	virtual void mouseReleaseEvent( QMouseEvent *event )
+	{
+		if (m_suppressClick)
+			m_suppressClick = false;
+		else
+			QListWidget::mouseReleaseEvent(event);
+	}
+
+	virtual void mouseDoubleClickEvent( QMouseEvent *event )
+	{
+		m_suppressClick = true;
+		QListWidget::mouseDoubleClickEvent(event);
+	}
+
+  private:
+	bool m_suppressClick;
 };
 
 class UserListViewItem : public QListWidgetItem {
@@ -154,9 +182,9 @@ KGreeter::KGreeter( bool framed )
 
 	if (_userList) {
 		userView = new UserListView( this );
-		connect( userView, SIGNAL(itemPressed( QListWidgetItem * )),
+		connect( userView, SIGNAL(itemClicked( QListWidgetItem * )),
 		         SLOT(slotUserClicked( QListWidgetItem * )) );
-		connect( userView, SIGNAL(itemActivated( QListWidgetItem * )),
+		connect( userView, SIGNAL(itemDoubleClicked( QListWidgetItem * )),
 		         SLOT(accept()) );
 	}
 	if (_userCompletion)
@@ -333,7 +361,7 @@ KGreeter::insertUsers()
 		for (setpwent(); (ps = getpwent()) != 0;) {
 			if (*ps->pw_dir && *ps->pw_shell &&
 			    (ps->pw_uid >= (unsigned)_lowUserId ||
-			     !ps->pw_uid && _showRoot) &&
+			     (!ps->pw_uid && _showRoot)) &&
 			    ps->pw_uid <= (unsigned)_highUserId &&
 			    !noUsers.hasUser( ps->pw_name ) &&
 			    !noUsers.hasGroup( ps->pw_gid ))
@@ -352,7 +380,7 @@ KGreeter::insertUsers()
 			for (setpwent(); (ps = getpwent()) != 0;) {
 				if (*ps->pw_dir && *ps->pw_shell &&
 				    (ps->pw_uid >= (unsigned)_lowUserId ||
-				     !ps->pw_uid && _showRoot) &&
+				     (!ps->pw_uid && _showRoot)) &&
 				    ps->pw_uid <= (unsigned)_highUserId &&
 				    (users.hasUser( ps->pw_name ) ||
 				     users.hasGroup( ps->pw_gid )))
@@ -416,9 +444,9 @@ KGreeter::insertSessions()
 				                  dsk.readEntry( "TryExec" ) ).isEmpty())),
 				            dsk.readEntry( "Exec" ).toLatin1() );
 			}
-	putSession( "default", i18n("Default"), false, "default" );
-	putSession( "custom", i18n("Custom"), false, "custom" );
-	putSession( "failsafe", i18n("Failsafe"), false, "failsafe" );
+	putSession( "default", i18nc("@item:inlistbox session type", "Default"), false, "default" );
+	putSession( "custom", i18nc("@item:inlistbox session type", "Custom"), false, "custom" );
+	putSession( "failsafe", i18nc("@item:inlistbox session type", "Failsafe"), false, "failsafe" );
 	qSort( sessionTypes );
 	for (int i = 0; i < sessionTypes.size() && !sessionTypes[i].hid; i++) {
 		sessionTypes[i].action = sessGroup->addAction( sessionTypes[i].name );
@@ -471,7 +499,7 @@ KGreeter::slotUserClicked( QListWidgetItem *item )
 void
 KGreeter::slotSessionSelected()
 {
-	verify->gplugActivity();
+	verify->gplugChanged();
 }
 
 void
@@ -483,10 +511,7 @@ KGreeter::reject()
 void
 KGreeter::accept()
 {
-	if (userView && userView->hasFocus())
-		slotUserClicked( userView->currentItem() );
-	else
-		verify->accept();
+	verify->accept();
 }
 
 void // private
@@ -496,7 +521,9 @@ KGreeter::setPrevWM( QAction *wm )
 		if (curPrev)
 			curPrev->setText( sessionTypes[curPrev->data().toInt()].name );
 		if (wm)
-			wm->setText( sessionTypes[wm->data().toInt()].name + i18n(" (previous)") );
+			wm->setText( i18nc( "@item:inmenu session type",
+			                    "%1 (previous)",
+			                    sessionTypes[wm->data().toInt()].name ) );
 		curPrev = wm;
 	}
 }
@@ -661,7 +688,6 @@ KStdGreeter::KStdGreeter()
 		QBoxLayout *ex_box = new QVBoxLayout( this );
 		main_box = new QHBoxLayout();
 		ex_box->addLayout( main_box );
-		main_box->setParent( ex_box );
 		ex_box->addWidget( consoleView );
 	} else
 #endif
@@ -676,7 +702,6 @@ KStdGreeter::KStdGreeter()
 
 	QBoxLayout *inner_box = new QVBoxLayout();
 	main_box->addLayout( inner_box );
-	inner_box->setParent( main_box );
 	inner_box->setSpacing( rs );
 
 	if (!_authorized && _authComplain) {
@@ -736,10 +761,10 @@ KStdGreeter::KStdGreeter()
 			main_box->addWidget( pixLabel, 0, Qt::AlignCenter );
 	}
 
-	goButton = new QPushButton( i18n("L&ogin"), this );
+	goButton = new QPushButton( i18nc("@action:button", "L&ogin"), this );
 	goButton->setDefault( true );
 	connect( goButton, SIGNAL(clicked()), SLOT(accept()) );
-	QPushButton *menuButton = new QPushButton( i18n("&Menu"), this );
+	QPushButton *menuButton = new QPushButton( i18nc("@action:button", "&Menu"), this );
 	//helpButton
 
 	QWidget *prec;
@@ -756,7 +781,6 @@ KStdGreeter::KStdGreeter()
 		                 pluginList, KGreeterPlugin::Authenticate,
 		                 KGreeterPlugin::Login );
 	inner_box->addLayout( sverify->getLayout() );
-	sverify->getLayout()->setParent( inner_box );
 	QMenu *plugMenu = sverify->getPlugMenu();
 	sverify->selectPlugin( curPlugin );
 	verify = sverify;
@@ -765,24 +789,23 @@ KStdGreeter::KStdGreeter()
 
 	QBoxLayout *hbox2 = new QHBoxLayout();
 	inner_box->addLayout( hbox2 );
-	hbox2->setParent( inner_box );
 	hbox2->addWidget( goButton );
 	hbox2->addStretch( 1 );
 	hbox2->addWidget( menuButton );
 	hbox2->addStretch( 1 );
 
 	if (sessMenu->actions().count() > 1) {
-		inserten( i18n("Session &Type"), Qt::ALT+Qt::Key_T, sessMenu );
+		inserten( i18nc("@title:menu", "Session &Type"), Qt::ALT+Qt::Key_T, sessMenu );
 		needSep = true;
 	}
 
 	if (plugMenu) {
-		inserten( i18n("&Authentication Method"), Qt::ALT+Qt::Key_A, plugMenu );
+		inserten( i18nc("@title:menu", "&Authentication Method"), Qt::ALT+Qt::Key_A, plugMenu );
 		needSep = true;
 	}
 
 #ifdef XDMCP
-	completeMenu( LOGIN_LOCAL_ONLY, ex_choose, i18n("&Remote Login"), Qt::ALT+Qt::Key_R );
+	completeMenu( LOGIN_LOCAL_ONLY, ex_choose, i18nc("@action:inmenu", "&Remote Login"), Qt::ALT+Qt::Key_R );
 #else
 	completeMenu();
 #endif
@@ -856,7 +879,7 @@ KThemedGreeter::KThemedGreeter( KdmThemer *_themer )
 	pam_error = themer->findNode( "pam-error" );
 	KdmLabel *pam_error_label = qobject_cast<KdmLabel *>(pam_error);
 	if (pam_error_label)
-		pam_error_label->setText( i18n("Login Failed.") );
+		pam_error_label->setText( i18n("Login failed") );
 	timed_label = themer->findNode( "timed-label" );
 
 	KdmItem *itm;
@@ -905,18 +928,18 @@ KThemedGreeter::KThemedGreeter( KdmThemer *_themer )
 		}
 	} else {
 		if (sessMenu->actions().count() > 1) {
-			inserten( i18n("Session &Type"), Qt::ALT+Qt::Key_T, sessMenu );
+			inserten( i18nc("@title:menu", "Session &Type"), Qt::ALT+Qt::Key_T, sessMenu );
 			needSep = true;
 		}
 	}
 
 	if (plugMenu) {
-		inserten( i18n("&Authentication Method"), Qt::ALT+Qt::Key_A, plugMenu );
+		inserten( i18nc("@title:menu", "&Authentication Method"), Qt::ALT+Qt::Key_A, plugMenu );
 		needSep = true;
 	}
 
 #ifdef XDMCP
-	completeMenu( LOGIN_LOCAL_ONLY, ex_choose, i18n("&Remote Login"), Qt::ALT+Qt::Key_R );
+	completeMenu( LOGIN_LOCAL_ONLY, ex_choose, i18nc("@action:inmenu", "&Remote Login"), Qt::ALT+Qt::Key_R );
 #else
 	completeMenu();
 #endif
