@@ -26,7 +26,7 @@ DEALINGS IN THE SOFTWARE.
 
 #include <assert.h>
 
-#include "kdecoration_p.h"
+#include "kdecorationbridge.h"
 
 KDecorationFactory::KDecorationFactory()
     {
@@ -68,8 +68,8 @@ void KDecorationFactory::removeDecoration( KDecoration* deco )
 
 void KDecorationFactory::resetDecorations( unsigned long changed )
     {
-    for( QList< KDecoration* >::ConstIterator it = _decorations.begin();
-         it != _decorations.end();
+    for( QList< KDecoration* >::ConstIterator it = _decorations.constBegin();
+         it != _decorations.constEnd();
          ++it )
         (*it)->reset( changed );
     }
@@ -78,3 +78,39 @@ NET::WindowType KDecorationFactory::windowType( unsigned long supported_types, K
     {
     return bridge->windowType( supported_types );
     }
+
+QList< QList<QImage> > KDecorationFactoryUnstable::shadowTextures()
+    {
+    return QList< QList<QImage> >();
+    }
+
+int KDecorationFactoryUnstable::shadowTextureList( ShadowType type ) const
+    {
+    Q_UNUSED( type );
+    return -1;
+    }
+
+QList<QRect> KDecorationFactoryUnstable::shadowQuads( ShadowType type, QSize size ) const
+    {
+    Q_UNUSED( type );
+    Q_UNUSED( size );
+    return QList<QRect>();
+    }
+
+double KDecorationFactoryUnstable::shadowOpacity( ShadowType type ) const
+    {
+    Q_UNUSED( type );
+    return 1.0;
+    }
+
+double KDecorationFactoryUnstable::shadowBrightness( ShadowType type ) const
+    {
+    Q_UNUSED( type );
+    return 1.0;
+    }
+
+double KDecorationFactoryUnstable::shadowSaturation( ShadowType type ) const
+    {
+    Q_UNUSED( type );
+    return 1.0;
+    }
