@@ -27,7 +27,7 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include <ksessionmanager.h>
 #include <X11/SM/SMlib.h>
 #include <netwm_def.h>
-#include <qrect.h>
+#include <QRect>
 
 class QSocketNotifier;
 
@@ -56,7 +56,7 @@ struct SessionInfo
     bool keepBelow;
     bool skipTaskbar;
     bool skipPager;
-    bool userNoBorder;
+    bool noBorder;
     NET::WindowType windowType;
     QString shortcut;
     bool active; // means 'was active in the saved session'
