@@ -19,7 +19,7 @@
 #ifndef SHELLRUNNER_H
 #define SHELLRUNNER_H
 
-#include <plasma/abstractrunner.h>
+#include <Plasma/AbstractRunner>
 
 class QWidget;
 class QAction;
@@ -36,13 +36,11 @@ class ShellRunner : public Plasma::AbstractRunner
         ShellRunner(QObject *parent, const QVariantList &args);
         ~ShellRunner();
 
-        void createMatchOptions(QWidget* parent);
         void match(Plasma::RunnerContext &context);
         void run(const Plasma::RunnerContext &context, const Plasma::QueryMatch &action);
 
-
-    public slots:
-        void setRunInTerminal(bool inTerminal);
+    protected:
+        void reloadConfig();
 
     private:
         bool m_enabled;
